@@ -1,12 +1,12 @@
 use strict;
+use warnings FATAL => 'all';
 require 5.010;
 use feature 'say';
 use DDP {output => 'STDOUT', array_max => 10, show_memsize => 0};
 use Devel::Confess 'color';
 use Cwd 'getcwd';
-use warnings FATAL => 'all';
 package SimpleFlow;
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 use Time::HiRes;
 use Term::ANSIColor;
 use Scalar::Util 'openhandle';
@@ -29,6 +29,7 @@ sub say2 { # say to both command line and log file
 	$msg = "\@ $c[1] line $c[2] $msg";
 	say $msg;
 	say $fh $msg;
+	return $msg;
 }
 
 sub task {
@@ -88,7 +89,6 @@ sub task {
 		if (scalar @missing_files > 0) {
 			say STDERR 'this list of arguments:';
 			p $args;
-			my $dir = getcwd();
 			say STDERR 'Cannot run because these files are either missing or unreadable in: ' . getcwd();
 			p @missing_files;
 			die 'the above files are missing or are not readable';
